""" API specific """
OAUTH = 'oauth'
ACCESS_TOKEN = 'access_token'


""" API endpoints """
PERSON = 'person'
PERSON_CALENDAR_CLASSES = 'person/calendar/classes'
PERSON_CALENDAR_EVALUATIONS = 'person/calendar/evaluations'
PERSON_CURRICULUM = 'person/curriculum'
PERSON_COURSES = 'person/courses'
PERSON_EVALUATIONS = 'person/evaluations'
PERSON_EVALUATION = 'person/evaluations/:id'
ABOUT = 'about'
ACADEMIC_TERMS = 'academicterms'
COURSES = 'courses'
COURSE = 'courses/:id'
COURSE_EVALUATIONS = 'courses/:id/evaluations'
COURSE_GROUPS = 'courses/:id/groups'
COURSE_SCHEDULE = 'courses/:id/schedule'
COURSE_STUDENTS = 'courses/:id/students'
EVALUATIONS = 'evaluations'
SCHEDULE = 'schedule'
GROUPS = 'groups'
STUDENTS = 'students'
DEGREES = 'degrees'
DEGREE = 'degrees/:id'
DEGREE_COURSES = 'degrees/:id/courses'
CALENDAR = 'calendar'
PAYMENTS = 'payments'
SPACES = 'spaces'
SPACE = 'spaces/:id'
CLASSES = 'classes'
CURRICULUM = 'curriculum'
REFRESH_TOKEN = 'refresh_token'
CURRICULUM = 'curriculum'
